@@ -1,11 +1,13 @@
 import random
 
-class Randomizer():
-    '''
+
+class Randomizer:
+    """
     Class to generate random display numbers between a minimum and maximum
     value. Note that the maximum value can be exceeded if every value between
     the generated and maximum value is already in use.
-    '''
+    """
+
     def __init__(self, min_display_nr=1000, max_display_nr=1100):
         self.min = min_display_nr
         self.delta = max_display_nr - min_display_nr
@@ -13,10 +15,10 @@ class Randomizer():
         random.seed()
 
     def generate(self):
-        '''
+        """
         Generate a random display number
 
         :rtype: int
-        '''
+        """
 
-        return self.min + random.randint(0, self.delta)
\ No newline at end of file
+        return self.min + random.randint(0, self.delta)
